@@ -145,6 +145,27 @@ sub as_ascii {
     return $output;
 }
 
+=head2 max_x( $line )
+
+Finds the last defined pixel on a given line. Useful for optimizing writes
+in formats where width matters. Returns undef for a missing line.
+
+=cut
+
+sub max_x {
+    my( $self, $y ) = @_;
+    my $line = $self->pixeldata->[ $y ];
+
+    return unless $line;
+
+    my $x;
+    for( 0..@$line - 1 ) {
+        $x = $_ if defined $line->[ $_ ];
+    }
+
+    return $x;
+}
+
 no Moose;
 
 __PACKAGE__->meta->make_immutable;
